;**************************************************************************
;* FileName	: WAIT.INC
;* Date 	: 14.01.2008
;* File version : v1.02
;*
;* Author	: MIKO, Imre
;* Company	:
;* Homepage	: http://majki.fw.hu
;* E-mail	: majki@fw.hu
;*
;*-------------------------------------------------------------------------
;*
;* Description	: Delay functions
;*		  ==================================
;*		  These functions are called by WAIT macro.
;* 
;*-------------------------------------------------------------------------
;* Needed defines in main-modul:
;* 
;* core_freq	EQU	xtal_freq/4	; core operating frequency
;*
;*-------------------------------------------------------------------------
;* Other possible defines in main-modul:
;*
;* #define DEBUG			; for some debug message
;* #define NO_DELAY			; for fast simulation
;* #define PIC_12BIT			; 12 bit device (e.g. 10f20x)
;*
;**************************************************************************
;* Revision History:
;*
;* 1.00	  21/08/2000 	Initial Release
;* 1.02   14/01/2008    - support for 12bit devices (do not use decw)
;*
;**************************************************************************

;***** VARIABLES **********************************************************

	ifdef PIC_12BIT
		cblock
		  delay_10
		endc
	endif

	ifdef INC_DELAY_1000
		cblock
		  delay_1000
		endc
	endif

	ifdef INC_DELAY_100000
		cblock
		  delay_100000
		endc
	endif


;***** DELAY FUNCTION *****************************************************
;* wait w * 100000
;* Input : w				; time to delay
;* Output: w = 0			;
;* Clock : w * 100000 (-3)		; -3 for movlw and call
;**************************************************************************
		ifdef INC_DELAY_100000
delay_Wx100000	
		movwf	delay_100000
delay_e5_1	nop2
		movlw	99		; 1       \
		call	delay_Wx1000	; 99000    \ 99.992
		movlw	99		; 1        /
		call	delay_Wx10	; 990     /
		
		decfsz	delay_100000,f
		goto	delay_e5_2
		retlw	0

delay_e5_2	nop2
		nop
		goto	delay_e5_1

		endif



;***** DELAY FUNCTION *****************************************************
;* wait w * 1000
;* Input : w				; time to delay
;* Output: w = 0			;
;* Clock : w * 1000 (-3)		; -3 for movlw and call
;**************************************************************************
		ifdef INC_DELAY_1000
delay_Wx1000	
		movwf	delay_1000
		goto	delay_e3_2

delay_e3_1	nop2
		nop2
		nop2
		nop

delay_e3_2	movlw	99
		call	delay_Wx10	; 990
		decfsz	delay_1000,f
		goto	delay_e3_1
	
		retlw	0

		endif

;***** DELAY FUNCTION *****************************************************
;* wait w * 10 cycles
;* Input : w				; time to delay
;* Output: w = 0			;
;* Clock : w * 10 (-3)                  ; -3 for movlw and call
;**************************************************************************
	ifdef INC_DELAY_10
	  ifndef PIC_12BIT

; ----- delay function for 14..16 bit instruction length ------------------

delay_Wx10	nop
		nop2
		decw
		skipnz
		return
		nop2
		goto	delay_Wx10

	  else

; ------ delay function for 12 bit instruction length ---------------------

		messg "WAIT: PIC_12BIT is set!"
delay_Wx10	movwf	delay_10
delay_Wx10_1	nop2
		decf	delay_10,f
		skipnz
		return
		nop
		nop2
		goto	delay_Wx10_1	

	  endif
	endif


;**************************************************************************








